@@ -47,7 +47,7 @@ class dvd_menu(devedeng.interface_manager.interface_manager):
 
         self.add_group("position_horizontal", ["left", "center", "right"], "center", self.update_preview)
         self.add_group("at_startup", ["menu_show_at_startup", "play_first_title_at_startup"], "menu_show_at_startup")
-        self.add_group("play_all", ["menu_play_all", "menu_no_play_all"], "menu_no_play_all", self.update_preview)
+        self.add_toggle("play_all_c", False, self.update_preview)
 
         self.add_integer_adjustment("sound_length", 30)
 
@@ -254,7 +254,7 @@ class dvd_menu(devedeng.interface_manager.interface_manager):
     def write_text(self,text,text_type,xl,xr,y,alignment):
         """ Renders a line of text, in the rectangle delimited by xl,y-h;xr,y+h, with the specified alignment """
 
-        if text == None:
+        if text is None:
             return
 
         if text_type == "title":
@@ -298,7 +298,7 @@ class dvd_menu(devedeng.interface_manager.interface_manager):
         elif alignment == "center":
             x = ((xl + xr) / 2.0) - (extents[2] / 2.0)
 
-        if (bgcolor != None):
+        if (bgcolor is not None):
             self.cr.move_to(x+extents[0]+2,y-(extents[3]/2.0)-extents[1]+2)
             self.cr.set_source_rgba(bgcolor[0],bgcolor[1],bgcolor[2],bgcolor[3])
             self.cr.show_text(text)
@@ -339,7 +339,7 @@ class dvd_menu(devedeng.interface_manager.interface_manager):
 
         coordinates = []
 
-        if self.sf == None:
+        if self.sf is None:
             self.sf=cairo.ImageSurface(cairo.FORMAT_ARGB32,720,int(self.y))
             self.cr=cairo.Context(self.sf)
 
@@ -377,7 +377,7 @@ class dvd_menu(devedeng.interface_manager.interface_manager):
 
         entry_height = self.cached_menu_size + self.entry_vertical_margin * 2.0 + self.entry_separation
         entries_per_page = int((self.y - top_margin_p - bottom_margin_p) / entry_height)
-        if (self.play_all == "menu_play_all"):
+        if (self.play_all_c):
             entries_per_page -= 1
         n_entries = len(self.title_list)
         if (n_entries > entries_per_page):
@@ -392,14 +392,14 @@ class dvd_menu(devedeng.interface_manager.interface_manager):
         if (page_number >= self.pages) and (page_number > 0):
             page_number -= 1
 
-        if self.wcurrent_page != None:
+        if self.wcurrent_page is not None:
             self.wcurrent_page.set_text(_("Page %(X)d of %(Y)d") % {"X":page_number+1 , "Y":self.pages})
         xl = left_margin_p
         xr = 720.0 - right_margin_p
         y = top_margin_p + entry_height/2.0
         height = (self.cached_menu_size + self.entry_vertical_margin) / 2.0
         
-        if (self.play_all == "menu_play_all"):
+        if (self.play_all_c):
             coordinates.append([xl, y-height, xr, y+height, "play_all"])
             if paint_background:
                 self.paint_base(xl, xr, y, 0)
@@ -502,7 +502,7 @@ class dvd_menu(devedeng.interface_manager.interface_manager):
         """ Callback to repaint the menu preview window when it
             sends the EXPOSE event """
 
-        if (self.sf == None):
+        if (self.sf is None):
             self.paint_menu(True, self.wshow_as_selected.get_active(), False, self.current_shown_page)
             if (self.current_shown_page >= self.pages):
                 self.current_shown_page = self.pages
